import Foundation
import WatchKit

class PostDetailsController: WKInterfaceController {
  @IBOutlet weak var image: WKInterfaceImage!
  @IBOutlet weak var categoryLabel: WKInterfaceLabel!
  @IBOutlet weak var titleLabel: WKInterfaceLabel!
  @IBOutlet weak var dateLabel: WKInterfaceLabel!
  @IBOutlet weak var urlLabel: WKInterfaceLabel!

  var post: Post!

  lazy var dateFormatter: NSDateFormatter = {
    let dateFmt = NSDateFormatter()
    dateFmt.dateStyle = .MediumStyle
    dateFmt.timeStyle = .NoStyle
    return dateFmt
    }()

  override func awakeWithContext(context: AnyObject!) {
    super.awakeWithContext(context)

    if let post = context as? Post {
      self.post = post
    }
  }

  override func willActivate() {
    super.willActivate()

    if post == nil {
      return
    }

    if post.category == "Announcements" {
      image.setImageNamed("announcement")
    } else if post.category == "Podcast Episodes" {
      image.setImageNamed("podcast")
    } else if post.category == "Video Tutorials" {
      image.setImageNamed("video")
    } else {
      image.setImageNamed("written")
    }

    categoryLabel.setText(post.category)
    titleLabel.setText(post.title)
    dateLabel.setText(dateFormatter.stringFromDate(post.timestamp))
    urlLabel.setText(post.link)
  }
}
