import WatchKit
import Foundation

class PostListController: WKInterfaceController {

  @IBOutlet weak var table: WKInterfaceTable!

  let coreDataStack = CoreDataStack()
  var posts = [Post]()

  lazy var dateFormatter: NSDateFormatter = {
    let dateFmt = NSDateFormatter()
    dateFmt.dateStyle = .MediumStyle
    dateFmt.timeStyle = .NoStyle
    return dateFmt
  }()

  override func awakeWithContext(context: AnyObject!) {
    super.awakeWithContext(context)

    // Configure interface objects here.
    NSLog("%@ awake", self)
  }

  override func willActivate() {
    // This method is called when watch view controller is about to be visible to user
    super.willActivate()
    NSLog("%@ will activate", self)

    posts = coreDataStack.allPosts()

    if posts.count != table.numberOfRows {
      table.setNumberOfRows(posts.count, withRowType: "PostRowType")
    }
    
    for (index, post) in enumerate(posts) {
      if let row = table.rowControllerAtIndex(index) as? PostRowController {
        row.titleLabel.setText(post.title)
        row.dateLabel.setText(dateFormatter.stringFromDate(post.timestamp))

        if post.category == "Announcements" {
          row.image.setImageNamed("announcement")
        } else if post.category == "Podcast Episodes" {
          row.image.setImageNamed("podcast")
        } else if post.category == "Video Tutorials" {
          row.image.setImageNamed("video")
        } else {
          row.image.setImageNamed("written")
        }
      }
    }
  }

  override func table(table: WKInterfaceTable, didSelectRowAtIndex rowIndex: Int) {
    NSLog("Showing post details from code")
    let post = posts[rowIndex]
    pushControllerWithName("PostDetailsController", context: post)
  }

  override func contextForSegueWithIdentifier(segueIdentifier: String, inTable table: WKInterfaceTable, rowIndex: Int) -> AnyObject? {
    NSLog("Showing post details from segue")
    return posts[rowIndex]
  }

  override func didDeactivate() {
    // This method is called when watch view controller is no longer visible
    NSLog("%@ did deactivate", self)
    super.didDeactivate()
  }

}
